@@ -1,4 +1,4 @@
 #! /usr/bin/env bash
 $EXTRACTRC `find . -name \*.ui` >> rc.cpp || exit 11
-$XGETTEXT `find . -name \*.cpp` -o $podir/kwin_effects.pot
+$XGETTEXT `find . -name \*.cpp -o -name \*.h` -o $podir/kwin_effects.pot
 rm -f rc.cpp
