@@ -41,6 +41,7 @@ RuleItem::RuleItem(const QString &key,
     , m_enabled(false)
     , m_policy(new RulePolicy(policyType))
     , m_options(nullptr)
+    , m_optionsMask(0U - 1)
 {
     reset();
 }
@@ -54,7 +55,7 @@ RuleItem::~RuleItem()
 void RuleItem::reset()
 {
     m_enabled = hasFlag(AlwaysEnabled) | hasFlag(StartEnabled);
-    m_value = typedValue(QVariant(), m_type);
+    m_value = typedValue(QVariant());
     m_suggestedValue = QVariant();
     m_policy->resetValue();
     if (m_options) {
@@ -130,7 +131,7 @@ void RuleItem::setValue(QVariant value)
     if (m_options && m_type == Option) {
         m_options->setValue(value);
     }
-    m_value = typedValue(value, m_type);
+    m_value = typedValue(value);
 }
 
 QVariant RuleItem::suggestedValue() const
@@ -143,7 +144,7 @@ void RuleItem::setSuggestedValue(QVariant value, bool forceValue)
     if (forceValue) {
         setValue(value);
     }
-    m_suggestedValue = value.isNull() ? QVariant() : typedValue(value, m_type);
+    m_suggestedValue = value.isNull() ? QVariant() : typedValue(value);
 }
 
 QVariant RuleItem::options() const
@@ -157,13 +158,25 @@ QVariant RuleItem::options() const
 void RuleItem::setOptionsData(const QList<OptionsModel::Data> &data)
 {
     if (!m_options) {
-        if (m_type != Option && m_type != FlagsOption) {
+        if (m_type != Option && m_type != NetTypes) {
             return;
         }
         m_options = new OptionsModel();
     }
     m_options->updateModelData(data);
     m_options->setValue(m_value);
+
+    if (m_type == NetTypes) {
+        m_optionsMask = 0;
+        for (const OptionsModel::Data &dataItem : data) {
+            m_optionsMask += 1 << dataItem.value.toUInt();
+        }
+    }
+}
+
+uint RuleItem::optionsMask() const
+{
+    return m_optionsMask;
 }
 
 int RuleItem::policy() const
@@ -191,9 +204,9 @@ QString RuleItem::policyKey() const
     return m_policy->policyKey(m_key);
 }
 
-QVariant RuleItem::typedValue(const QVariant &value, const RuleItem::Type type)
+QVariant RuleItem::typedValue(const QVariant &value) const
 {
-    switch (type) {
+    switch (type()) {
         case Undefined:
         case Option:
             return value;
@@ -202,12 +215,13 @@ QVariant RuleItem::typedValue(const QVariant &value, const RuleItem::Type type)
         case Integer:
         case Percentage:
             return value.toInt();
-        case FlagsOption:
-            // HACK: Currently, the only user of this is "types" property
-            if (value.toInt() == -1) { //NET:AllTypesMask
-                return 0x3FF - 0x040;  //All possible flags minus NET::Override (deprecated)
+        case NetTypes: {
+            const uint typesMask = value.toUInt() & optionsMask();  // filter by the allowed mask in the model
+            if (typesMask == 0 || typesMask == optionsMask()) {     // if no types or all of them are selected
+                return 0U - 1;                                      // return an all active mask (NET:AllTypesMask)
             }
-            return value.toInt();
+            return typesMask;
+        }
         case Point:
             return value.toPoint();
         case Size:
