@@ -24,7 +24,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "kwinglutils_funcs.h"
 #include <epoxy/gl.h>
 
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QStringList>
 #include <QDebug>
 #include <QOpenGLContext>
@@ -94,14 +94,13 @@ static qint64 getKernelVersion()
 }
 
 // Extracts the portion of a string that matches a regular expression
-static QString extract(const QString &string, const QString &match, int offset = 0)
+static QString extract(const QString &text, const QString &pattern)
 {
-    QString result;
-    QRegExp rx(match);
-    int pos = rx.indexIn(string, offset);
-    if (pos != -1)
-        result = string.mid(pos, rx.matchedLength());
-    return result;
+    const QRegularExpression regexp(pattern);
+    const QRegularExpressionMatch match = regexp.match(text);
+    if (!match.hasMatch())
+        return QString();
+    return match.captured();
 }
 
 static ChipClass detectRadeonClass(const QByteArray &chipset)
@@ -687,7 +686,8 @@ void GLPlatform::detect(OpenGLPlatformInterface platformInterface)
         }
     } else {
         const QByteArray extensions = (const char *) glGetString(GL_EXTENSIONS);
-        m_extensions = QSet<QByteArray>::fromList(extensions.split(' '));
+        QList<QByteArray> extensionsList = extensions.split(' ');
+        m_extensions = {extensionsList.constBegin(), extensionsList.constEnd()};
     }
 
     // Parse the Mesa version
@@ -905,12 +905,12 @@ void GLPlatform::detect(OpenGLPlatformInterface platformInterface)
         }
 
         // softpipe
-        else if (m_chipset == "softpipe") {
+        else if (m_vendor == "VMware, Inc." && m_chipset == "softpipe" ) {
             m_driver = Driver_Softpipe;
         }
 
         // llvmpipe
-        else if (m_chipset == "llvmpipe") {
+        else if (m_vendor == "VMware, Inc." && m_chipset == "llvmpipe") {
             m_driver = Driver_Llvmpipe;
         }
 
