@@ -354,22 +354,24 @@ void Decoration::init()
         connect(m_extendedBorders, &KWin::Borders::topChanged, this, &Decoration::updateExtendedBorders);
         connect(m_extendedBorders, &KWin::Borders::bottomChanged, this, &Decoration::updateExtendedBorders);
     }
-    connect(client().data(), &KDecoration2::DecoratedClient::maximizedChanged, this, &Decoration::updateBorders, Qt::QueuedConnection);
-    connect(client().data(), &KDecoration2::DecoratedClient::shadedChanged, this, &Decoration::updateBorders);
+
+    auto decorationClient = clientPointer();
+    connect(decorationClient, &KDecoration2::DecoratedClient::maximizedChanged, this, &Decoration::updateBorders, Qt::QueuedConnection);
+    connect(decorationClient, &KDecoration2::DecoratedClient::shadedChanged, this, &Decoration::updateBorders);
     updateBorders();
     if (m_view) {
         auto resizeWindow = [this] {
             QRect rect(QPoint(0, 0), size());
-            if (m_padding && !client().data()->isMaximized()) {
+            if (m_padding && !clientPointer()->isMaximized()) {
                 rect = rect.adjusted(-m_padding->left(), -m_padding->top(), m_padding->right(), m_padding->bottom());
             }
             m_view->setGeometry(rect);
         };
         connect(this, &Decoration::bordersChanged, this, resizeWindow);
-        connect(client().data(), &KDecoration2::DecoratedClient::widthChanged, this, resizeWindow);
-        connect(client().data(), &KDecoration2::DecoratedClient::heightChanged, this, resizeWindow);
-        connect(client().data(), &KDecoration2::DecoratedClient::maximizedChanged, this, resizeWindow);
-        connect(client().data(), &KDecoration2::DecoratedClient::shadedChanged, this, resizeWindow);
+        connect(decorationClient, &KDecoration2::DecoratedClient::widthChanged, this, resizeWindow);
+        connect(decorationClient, &KDecoration2::DecoratedClient::heightChanged, this, resizeWindow);
+        connect(decorationClient, &KDecoration2::DecoratedClient::maximizedChanged, this, resizeWindow);
+        connect(decorationClient, &KDecoration2::DecoratedClient::shadedChanged, this, resizeWindow);
         resizeWindow();
         updateBuffer();
     } else {
@@ -400,7 +402,7 @@ void Decoration::setupBorders(QQuickItem *item)
 void Decoration::updateBorders()
 {
     KWin::Borders *b = m_borders;
-    if (client().data()->isMaximized() && m_maximizedBorders) {
+    if (clientPointer()->isMaximized() && m_maximizedBorders) {
         b = m_maximizedBorders;
     }
     if (!b) {
@@ -430,7 +432,7 @@ void Decoration::updateShadow()
     const auto oldShadow = shadow();
     if (m_padding &&
             (m_padding->left() > 0 || m_padding->top() > 0 || m_padding->right() > 0 || m_padding->bottom() > 0) &&
-            !client().data()->isMaximized()) {
+            !clientPointer()->isMaximized()) {
         if (oldShadow.isNull()) {
             updateShadow = true;
         } else {
@@ -564,15 +566,15 @@ void Decoration::updateExtendedBorders()
     int extBottom = m_extendedBorders->bottom();
 
     if (settings()->borderSize() == KDecoration2::BorderSize::None) {
-        if (!client().data()->isMaximizedHorizontally()) {
+        if (!clientPointer()->isMaximizedHorizontally()) {
             extLeft = qMax(m_extendedBorders->left(), extSize);
             extRight = qMax(m_extendedBorders->right(), extSize);
         }
-        if (!client().data()->isMaximizedVertically()) {
+        if (!clientPointer()->isMaximizedVertically()) {
             extBottom = qMax(m_extendedBorders->bottom(), extSize);
         }
 
-    } else if (settings()->borderSize() == KDecoration2::BorderSize::NoSides && !client().data()->isMaximizedHorizontally() ) {
+    } else if (settings()->borderSize() == KDecoration2::BorderSize::NoSides && !clientPointer()->isMaximizedHorizontally() ) {
         extLeft = qMax(m_extendedBorders->left(), extSize);
         extRight = qMax(m_extendedBorders->right(), extSize);
     }
@@ -585,7 +587,7 @@ void Decoration::updateBuffer()
     m_contentRect = QRect(QPoint(0, 0), m_view->bufferAsImage().size());
     if (m_padding &&
             (m_padding->left() > 0 || m_padding->top() > 0 || m_padding->right() > 0 || m_padding->bottom() > 0) &&
-            !client().data()->isMaximized()) {
+            !clientPointer()->isMaximized()) {
         m_contentRect = m_contentRect.adjusted(m_padding->left(), m_padding->top(), -m_padding->right(), -m_padding->bottom());
     }
     updateShadow();
@@ -594,7 +596,7 @@ void Decoration::updateBuffer()
 
 KDecoration2::DecoratedClient *Decoration::clientPointer() const
 {
-    return client().data();
+    return client().toStrongRef().data();
 }
 
 ThemeFinder::ThemeFinder(QObject *parent, const QVariantList &args)
