@@ -21,7 +21,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <abstract_client.h>
 #include <x11client.h>
 #include "cursor.h"
-#include "orientation_sensor.h"
 #include "utils.h"
 #include "settings.h"
 #include <workspace.h>
@@ -55,21 +54,8 @@ Screens::Screens(QObject *parent)
     , m_current(0)
     , m_currentFollowsMouse(false)
     , m_changedTimer(new QTimer(this))
-    , m_orientationSensor(new OrientationSensor(this))
     , m_maxScale(1.0)
 {
-    connect(this, &Screens::changed, this,
-        [this] {
-            int internalIndex = -1;
-            for (int i = 0; i < m_count; i++) {
-                if (isInternal(i)) {
-                    internalIndex = i;
-                    break;
-                }
-            }
-            m_orientationSensor->setEnabled(internalIndex != -1 && supportsTransformations(internalIndex));
-        }
-    );
 }
 
 Screens::~Screens()
@@ -190,7 +176,7 @@ void Screens::setCurrentFollowsMouse(bool follows)
 int Screens::current() const
 {
     if (m_currentFollowsMouse) {
-        return number(Cursor::pos());
+        return number(Cursors::self()->mouse()->pos());
     }
     AbstractClient *client = Workspace::self()->activeClient();
     if (client && !client->isOnScreen(m_current)) {
@@ -241,9 +227,16 @@ Qt::ScreenOrientation Screens::orientation(int screen) const
 void Screens::setConfig(KSharedConfig::Ptr config)
 {
     m_config = config;
-    if (m_orientationSensor) {
-        m_orientationSensor->setConfig(config);
-    }
+}
+
+int Screens::physicalDpiX(int screen) const
+{
+    return size(screen).width() / physicalSize(screen).width() * qreal(25.4);
+}
+
+int Screens::physicalDpiY(int screen) const
+{
+    return size(screen).height() / physicalSize(screen).height() * qreal(25.4);
 }
 
 } // namespace
