@@ -40,13 +40,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 class QOpenGLFramebufferObject;
 
-namespace KWayland
-{
-namespace Server
+namespace KWaylandServer
 {
 class SurfaceInterface;
 }
-}
 
 namespace KWin
 {
@@ -78,20 +75,20 @@ class KWIN_EXPORT Toplevel : public QObject
      *
      * @deprecated Use frameGeometry property instead.
      */
-    Q_PROPERTY(QRect geometry READ frameGeometry NOTIFY geometryChanged)
+    Q_PROPERTY(QRect geometry READ frameGeometry NOTIFY frameGeometryChanged)
 
     /**
      * This property holds rectangle that the pixmap or buffer of this Toplevel
      * occupies on the screen. This rectangle includes invisible portions of the
      * client, e.g. client-side drop shadows, etc.
      */
-    Q_PROPERTY(QRect bufferGeometry READ bufferGeometry NOTIFY geometryChanged)
+    Q_PROPERTY(QRect bufferGeometry READ bufferGeometry)
 
     /**
      * This property holds the geometry of the Toplevel, excluding invisible
      * portions, e.g. server-side and client-side drop-shadows, etc.
      */
-    Q_PROPERTY(QRect frameGeometry READ frameGeometry NOTIFY geometryChanged)
+    Q_PROPERTY(QRect frameGeometry READ frameGeometry NOTIFY frameGeometryChanged)
 
     /**
      * This property holds the position of the Toplevel's frame geometry.
@@ -279,7 +276,7 @@ class KWIN_EXPORT Toplevel : public QObject
      * Interface to the Wayland Surface.
      * Relevant only in Wayland, in X11 it will be nullptr
      */
-    Q_PROPERTY(KWayland::Server::SurfaceInterface *surface READ surface)
+    Q_PROPERTY(KWaylandServer::SurfaceInterface *surface READ surface)
 
     /**
      * Whether the window is a popup.
@@ -517,8 +514,8 @@ public:
     void setSkipCloseAnimation(bool set);
 
     quint32 surfaceId() const;
-    KWayland::Server::SurfaceInterface *surface() const;
-    void setSurface(KWayland::Server::SurfaceInterface *surface);
+    KWaylandServer::SurfaceInterface *surface() const;
+    void setSurface(KWaylandServer::SurfaceInterface *surface);
 
     const QSharedPointer<QOpenGLFramebufferObject> &internalFramebufferObject() const;
     QImage internalImageObject() const;
@@ -589,6 +586,10 @@ public:
 Q_SIGNALS:
     void opacityChanged(KWin::Toplevel* toplevel, qreal oldOpacity);
     void damaged(KWin::Toplevel* toplevel, const QRect& damage);
+    /**
+     * This signal is emitted when the Toplevel's frame geometry changes.
+     * @deprecated since 5.19, use frameGeometryChanged instead
+     */
     void geometryChanged();
     void geometryShapeChanged(KWin::Toplevel* toplevel, const QRect& old);
     void paddingChanged(KWin::Toplevel* toplevel, const QRect& old);
@@ -652,6 +653,11 @@ Q_SIGNALS:
      */
     void shadowChanged();
 
+    /**
+     * This signal is emitted when the Toplevel's frame geometry changes.
+     */
+    void frameGeometryChanged(KWin::Toplevel *toplevel, const QRect &oldGeometry);
+
 protected Q_SLOTS:
     /**
      * Checks whether the screen number for this Toplevel changed and updates if needed.
@@ -732,7 +738,7 @@ private:
     int m_screen;
     bool m_skipCloseAnimation;
     quint32 m_surfaceId = 0;
-    KWayland::Server::SurfaceInterface *m_surface = nullptr;
+    KWaylandServer::SurfaceInterface *m_surface = nullptr;
     // when adding new data members, check also copyToDeleted()
     qreal m_screenScale = 1.0;
 };
@@ -989,7 +995,7 @@ inline quint32 Toplevel::surfaceId() const
     return m_surfaceId;
 }
 
-inline KWayland::Server::SurfaceInterface *Toplevel::surface() const
+inline KWaylandServer::SurfaceInterface *Toplevel::surface() const
 {
     return m_surface;
 }
