@@ -26,12 +26,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "wayland_server.h"
 #include "workspace.h"
 #include "xkb.h"
-#include "xdgshellclient.h"
+#include "screenlockerwatcher.h"
 
-#include <KWayland/Server/display.h>
-#include <KWayland/Server/seat_interface.h>
-#include <KWayland/Server/textinput_interface.h>
-#include <KWayland/Server/surface_interface.h>
+#include <KWaylandServer/display.h>
+#include <KWaylandServer/seat_interface.h>
+#include <KWaylandServer/textinput_interface.h>
+#include <KWaylandServer/surface_interface.h>
 
 #include <KStatusNotifierItem>
 #include <KLocalizedString>
@@ -50,7 +50,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // xkbcommon
 #include <xkbcommon/xkbcommon.h>
 
-using namespace KWayland::Server;
+using namespace KWaylandServer;
 
 namespace KWin
 {
@@ -87,6 +87,8 @@ void VirtualKeyboard::init()
     }
     m_inputWindow->setProperty("__kwin_input_method", true);
 
+    connect(ScreenLockerWatcher::self(), &ScreenLockerWatcher::aboutToLock, this, &VirtualKeyboard::hide);
+
     if (waylandServer()) {
         m_enabled = !input()->hasAlphaNumericKeyboard();
         qCDebug(KWIN_VIRTUALKEYBOARD) << "enabled by default: " << m_enabled;
@@ -153,7 +155,7 @@ void VirtualKeyboard::init()
                         }
                     );
 
-                    auto newClient = waylandServer()->findAbstractClient(waylandServer()->seat()->focusedTextInputSurface());
+                    auto newClient = waylandServer()->findClient(waylandServer()->seat()->focusedTextInputSurface());
                     // Reset the old client virtual keybaord geom if necessary
                     // Old and new clients could be the same if focus moves between subsurfaces
                     if (newClient != m_trackedClient) {
@@ -163,7 +165,7 @@ void VirtualKeyboard::init()
                         m_trackedClient = newClient;
                     }
 
-                    m_trackedClient = waylandServer()->findAbstractClient(waylandServer()->seat()->focusedTextInputSurface());
+                    m_trackedClient = waylandServer()->findClient(waylandServer()->seat()->focusedTextInputSurface());
 
                     updateInputPanelState();
                 } else {
@@ -289,6 +291,7 @@ void VirtualKeyboard::hide()
     if (m_inputWindow.isNull()) {
         return;
     }
+    m_inputWindow->hide();
     qApp->inputMethod()->hide();
 }
 
